---------------------------
-- lets simplify a bit..
---------------------------
local gf = Glance.Functions
local gv = Glance.Variables
local ga = Glance.Arrays
local gb = Glance.Buttons
local gd = Glance.Data

---------------------------
-- create the button
---------------------------
gf.AddButton("Armor","LEFT")
local btn = gb.Armor
btn.text			  	= "Armor"
btn.enabled		   		= true
btn.events				= {"MERCHANT_SHOW","UNIT_DAMAGE","UPDATE_INVENTORY_DURABILITY"}
btn.update				= true
btn.tooltip		   		= true
btn.menu			  	= true
btn.save.perCharacter 	= {["autoRepair"] = true,["guildRepair"] = true}
btn.save.allowProfile 	= true

---------------------------
-- shortcuts
---------------------------
local spc = btn.save.perCharacter
local HEX = ga.colors.HEX
local tooltip = gf.Tooltip

---------------------------
-- variables
---------------------------
ga.slotItems = {
	"HEADSLOT",
	"SHOULDERSLOT",
	"CHESTSLOT",
	"WRISTSLOT",
	"HANDSSLOT",
	"WAISTSLOT",
	"LEGSSLOT",
	"FEETSLOT",
	"MAINHANDSLOT",
	"SECONDARYHANDSLOT",
	"BACKSLOT",
	"FINGER0SLOT",
	"FINGER1SLOT",
	"NECKSLOT",
	"TRINKET0SLOT",
	"TRINKET1SLOT",
}
gv.party.a["Armor"] = 0
gv.party.b["Armor"] = 0
gv.party.c["Armor"] = 0
gv.party.d["Armor"] = 0
gd.itemLevel = {
	--min,max,gray,white,green,blue,purple
	{1,60,20,38,56,60,92},       -- vanilla
	{60,70,60,81,100,115,164},   -- burning crusade
	{70,80,100,130,174,200,284},  -- lich king
	{80,85,200,284,318,352,416},  -- cataclysm
	{85,90,318,352,416,463,600}, -- pandaria
}

---------------------------
-- special handling
---------------------------
local ArmorTooltip = CreateFrame("GameTooltip","Glance_Tooltip_Armor",UIParent,"GameTooltipTemplate")
	
---------------------------
-- update
---------------------------
function gf.Armor.update(self, event, arg1)
	if btn.enabled and gv.loaded then -- loaded keeps it from launching when defined
		Glance.Debug("function","update","Armor")
		gf.setButtonText(btn.button,"Armor: ",gf.Armor.GetDurability().."%","","")
		-- auto repair
		if event == "MERCHANT_SHOW" then
			gf.Armor.repair()
		end
	end
end

---------------------------
-- tooltip
---------------------------
function gf.Armor.tooltip()
	Glance.Debug("function","tooltip","Armor")
	tooltip.Title("Armor", "GLD")
	
	-- repair line
	local TotalRepairCost = gf.Armor.checkInventory()
	if TotalRepairCost > 0 then
		tooltip.Line("The total cost to repair your armor is: "..GetCoinTextureString(TotalRepairCost,0), "WHT")
	else
		tooltip.Line("Your armor is fully repaired.", "WHT")
	end
	
	-- item levels
	local itemLevel, eItemLevel = GetAverageItemLevel()
	itemLevel = math.floor(itemLevel)
	eItemLevel = math.floor(eItemLevel)
	if itemLevel > 0 then
		tooltip.Space()
		tooltip.Line("Item Level (iLvl)", "GLD")
		tooltip.Double("Average Item Level",gf.Armor.level(itemLevel), "WHT", "WHT")
		tooltip.Double("Equipped Item Level",gf.Armor.level(eItemLevel), "WHT", "WHT")
	end
	
	-- party stats
	local GetNumPartyMembers, _ = GetNumSubgroupMembers()
	if ((GetNumPartyMembers ~= 0 and sender ~= UnitName("player")) or gv.Debug) and Glance_Local.Options.sendStats then
		gf.addonQuery("Armor")
		tooltip.Space()
		tooltip.Double("Party"..gf.crossRealm(), "(eLVL/iLVL)/DUR", "GLD", "GLD")	
		gf.partyTooltip("Armor")
	end	
	
	-- options and notes
	local tbl = {
		[1] = {["Auto-Repair"] = spc.autoRepair},
		[2] = {["Use Guild Funds"] = gf.Armor.canRepair()},
		[3] = {["Guild funds available today"] = gf.Armor.getGuildFunds()},
	}
	tooltip.Options(tbl)
	tooltip.Notes(nil,nil,"change Options",nil,"Guild funds can only be used if allowed by the guild")	
end

---------------------------
-- menu
---------------------------
function gf.Armor.menu(level,UIDROPDOWNMENU_MENU_VALUE)
	Glance.Debug("function","menu","Armor")
	level = level or 1
	if (level == 1) then
		gf.setMenuTitle("Armor Options")
		gf.setMenuHeader("Auto Repair","autorepair",level)
		gf.setMenuHeader("Use Guild Funds","guildrepair",level)
	end
	if (level == 2) then
		if gf.isMenuValue("autorepair") then
			gf.setMenuOption(spc.autoRepair==true,"On","On",level,function() spc.autoRepair=true; end)
			gf.setMenuOption(spc.autoRepair==false,"Off","Off",level,function() spc.autoRepair=false; end)
		end
		if gf.isMenuValue("guildrepair") then
			gf.setMenuOption(spc.guildRepair==true,"On","On",level,function() spc.guildRepair=true; end)
			gf.setMenuOption(spc.guildRepair==false,"Off","Off",level,function() spc.guildRepair=false; end)
		end
	end
end

---------------------------
-- messaging
---------------------------
function gf.Armor.Message()
	local itemLevel, eItemLevel = GetAverageItemLevel()
	itemLevel = math.floor(itemLevel)
	eItemLevel = math.floor(eItemLevel)
	return "|r("..gf.Armor.level(eItemLevel).."|r/"..gf.Armor.level(itemLevel).."|r)/"..gf.Armor.GetDurability().."%"
end

---------------------------
-- durability 
---------------------------
function gf.Armor.GetDurability()
	local have, most, pct = 0,0,0
	local sOut
	for i = 1, 19 do
		local current, max = GetInventoryItemDurability(i)
		if current ~= nil then
			have = have + current
			most = most + max
		end
	end
	pct = math.floor((have/most) * 100)
	if pct >= 75 then
		sOut = HEX.green..pct
	elseif pct < 75 and pct > 50 then
		sOut = HEX.yellow..pct
	else
		sOut = HEX.red..pct
	end
	return sOut or HEX.gray.."0"
end

---------------------------
-- repair costs
---------------------------
function gf.Armor.checkInventory()
	local TotalRepairCost = 0
	for i=1, #ga.slotItems do
		local slotId, textureName = GetInventorySlotInfo(ga.slotItems[i])
		local hasItem, hasCooldown, repairCost = Glance_Tooltip_Armor:SetInventoryItem("player", slotId);
		if hasItem then
			TotalRepairCost = TotalRepairCost + (repairCost or 0)
		end
	end
	Glance_Tooltip_Armor:Hide()
	return TotalRepairCost
end

---------------------------
-- armor repair
---------------------------
function gf.Armor.repair()
	Glance.Debug("function","repair","Armor")
	if CanMerchantRepair()==1 and spc.autoRepair then
		local cost, needed = GetRepairAllCost();
		if needed then
			if CanGuildBankRepair() and spc.guildRepair then
				local funds = GetGuildBankWithdrawMoney()
				if cost > funds then
					local funds = GetMoney()
					if cost > funds then
						gf.sendMSG("You don't have enough money for repair!");
					else
						RepairAllItems();
						PlaySound("LOOTWINDOWCOINSOUND")
						gf.sendMSG("There was not enough money in your daily guild bank allotment for repair.  Your items have been repaired from your own funds for "..GetCoinTextureString(cost,0))
					end
				else
					RepairAllItems(1)
					PlaySound("LOOTWINDOWCOINSOUND")
					gf.sendMSG("Your items have been repaired by the guild for "..GetCoinTextureString(cost,0))
					return
				end
			else
				local funds = GetMoney()
				if cost > funds then
					gf.sendMSG("You don't have enough money for repair!");
				else
					RepairAllItems();
					PlaySound("LOOTWINDOWCOINSOUND")
					gf.sendMSG("Your items have been repaired for "..GetCoinTextureString(cost,0))
				end
			end
		end
	end
end

---------------------------
-- item level
---------------------------
function gf.Armor.level(il)
	local ul = UnitLevel("player")
	local color = HEX.gray
	for k,v in ipairs(gd.itemLevel) do
		local lmin,lmax,gray,white,green,blue,purple = unpack(v)
		if ul > lmin and ul <= lmax then
			if il < gray then 
				color = HEX.gray
			elseif il < white then 
				color = HEX.white
			elseif il < green then 
				color = HEX.green
			elseif il < blue then 
				color = HEX.blue 
			elseif il <= purple then 
				color = HEX.purple 
			end
		end		
	end
	return color..il
end

---------------------------
-- return guild funds available
---------------------------
function gf.Armor.canRepair()
	local val
	if spc.guildRepair then val = "On" else val = "Off" end
	if not CanGuildBankRepair() then val=HEX.gray..val end
	return val
end

---------------------------
-- return guild funds available
---------------------------
function gf.Armor.getGuildFunds()
	if CanGuildBankRepair() then
		local GuildMoney = GetGuildBankWithdrawMoney()
		if GuildMoney == -1 then 
			return HEX.green.."Unlimited"
		elseif gf.matchSingle(tostring(GuildMoney),"+") then
			return HEX.red.."Err"
		else
			return GetCoinTextureString(math.ceil(GuildMoney),0)
		end
	end
	return nil
end

---------------------------
-- load on demand
---------------------------
if gv.loaded then
	gf.Enable("Armor")
end