---------------------------
-- lets simplify a bit..
---------------------------
local gf = Glance.Functions
local gv = Glance.Variables
local ga = Glance.Arrays
local gb = Glance.Buttons

---------------------------
-- create the button
---------------------------
gf.AddButton("Bags","LEFT")
local btn = gb.Bags
btn.text              = "Bags"
btn.events            = {"PLAYER_ENTERING_WORLD","BAG_UPDATE"}
btn.enabled           = true
btn.update            = true
btn.tooltip           = true
btn.click             = true
btn.menu              = true
btn.icon              = "INTERFACE\\ICONS\\INV_MISC_BAG_10"
btn.save.perCharacter = {["CountTradeBagSlots"] = false, ["Display"] = "Free", ["Title"] = "Icon"}
local spc = btn.save.perCharacter


ga.bags = {			
	["Free"] = 0,		
	["Used"] = 0,		
	["Total"] = 0,		
	["Used/Total"] = "0/0",
	["Free/Total"] = "0/0",
}

---------------------------
-- update
---------------------------
function gf.Bags.update()
	local btn  = gb.Bags
	if btn.enabled and gv.loaded then -- loaded keeps it from launching when defined	
		wipe(ga.bags)
		local HEX = ga.colors.HEX
		local totalSlots, usedSlots, availableSlots = 0,0,0
		for bag = 0, 4 do
			local total, used, available, isTradeBag = unpack(gf.Bags.getBagSlots(bag))		
			if isTradeBag then 
				if not spc.CountTradeBagSlots then
					total, used, available = 0, 0, 0
				end
			end
			totalSlots = totalSlots + total
			usedSlots = usedSlots + used
			availableSlots = availableSlots + available
		end
		ga.bags = {			
			["Free"] = availableSlots,		
			["Used"] = usedSlots,		
			["Total"] = totalSlots,		
			["Used/Total"] = usedSlots.."/"..totalSlots,
			["Free/Total"] = availableSlots.."/"..totalSlots,
		}
		local title = "Bags: "
		if spc.Title =="Icon" then title = gf.is(btn.icon,"display") end		
		if usedSlots == totalSlots then
			btn.button:SetText(title..HEX.red..ga.bags[spc.Display])
		else
			btn.button:SetText(title..HEX.green..ga.bags[spc.Display])
		end
		btn.button:SetWidth(btn.button:GetTextWidth())
	end
end

---------------------------
-- tooltip
---------------------------
function gf.Bags.tooltip()
	Glance.Debug("function","tooltip","Bags")
	local tooltip = gf.Tooltip
	local HEX = ga.colors.HEX
	tooltip.Title("Bag Space","GLD")
	tooltip.Double(" ", spc.Display, "WHT","GLD")
	local totalSlots, usedSlots, availableSlots = 0,0,0
	wipe(ga.bags)
	for bag = 0, 4 do
		local total, used, available, isTradeBag = unpack(gf.Bags.getBagSlots(bag))	
		if total > 0 then
			local color = HEX.white
			if isTradeBag then 
				color = HEX.red 
				if not spc.CountTradeBagSlots then
					total, used, available = 0, 0, 0
				end
			else 
				color = HEX.gold 
			end
			totalSlots = totalSlots + total
			usedSlots = usedSlots + used
			availableSlots = availableSlots + available
			if available == 0 then available = HEX.red..available end
			if total == 0 then total = HEX.red..total; used = HEX.red..used end
			local name = GetBagName(bag)
			local _,link,quality,_,_,_,_,_,_,icon = GetItemInfo(name)
			if quality == nil then
				name = "|r"..name
			else
				quality = select(4, GetItemQualityColor(quality)) or "ffffffff"
				name = "|c"..quality..name
			end
			if icon == nil then
				icon = gf.is(btn.icon,"tooltip")
			else
				icon = gf.is(icon,"tooltip")
			end
			local value = 0
			ga.bags[bag] = {			
				["Free"] = available,		
				["Used"] = used,		
				["Total"] = total,		
				["Used/Total"] = used.."/"..total,
				["Free/Total"] = available.."/"..total,
			}
			tooltip.Double(color..bag..") "..icon..name, ga.bags[bag][spc.Display], "WHT","GRN")
		end
	end
	ga.bags = {			
		["Free"] = availableSlots,		
		["Used"] = usedSlots,		
		["Total"] = totalSlots,		
		["Used/Total"] = usedSlots.."/"..totalSlots,
		["Free/Total"] = availableSlots.."/"..totalSlots,
	}
	tooltip.Double(" ", "-------------", "WHT","GLD")
	if availableSlots == 0 then availableSlots = HEX.red..availableSlots end
	tooltip.Double(" ", ga.bags[spc.Display], "WHT","GRN")
	tooltip.Space()
	tooltip.Line("Options", "GLD")
	tooltip.Double("Title",spc.Title,"WHT","GRN")
	tooltip.Double("Display",spc.Display,"WHT","GRN")
	if spc.CountTradeBagSlots then
		tooltip.Double("Count Trade Bags", "Yes", "WHT", "GRN")
	else
		tooltip.Double("Count Trade Bags", "No", "WHT", "RED")
	end
	tooltip.Space()
	tooltip.Line("(Click to toggle all bags)","WHT")
	tooltip.Line("(Right-Click to change Options)","WHT")
end

---------------------------
-- click
---------------------------
function gf.Bags.click(self, button, down)
	Glance.Debug("function","click","Bags")
	if (button == "LeftButton") then 
		ToggleAllBags();
	end
end

---------------------------
-- menu
---------------------------
function gf.Bags.menu(level,UIDROPDOWNMENU_MENU_VALUE)
	Glance.Debug("function","menu","Bags")
	local HEX = ga.colors.HEX
	level = level or 1
	if (level == 1) then
		gf.setInfo(nil,true,false,true,nil,HEX.white.."Bags Options","spacer",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Title","title",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Display","display",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Count Trade Bags","tradebags",level,nil)
	end
	if (level == 2) then
		--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func,icon,keepShown,notRadio	
		if UIDROPDOWNMENU_MENU_VALUE == "title" then
			local checked, func
			if spc.Title == "Text" then checked = true else checked = false end
				func = function() spc.Title = "Text"; gf.Bags.update() end;
				gf.setInfo(nil,false,false,false,checked,"Text","text",level,func,nil,nil,true)
			if spc.Title == "Icon" then checked = true else checked = false end
				func = function() spc.Title = "Icon"; gf.Bags.update() end;
				gf.setInfo(nil,false,false,false,checked,"Icon","icon",level,func,nil,nil,true)			
		end
		if UIDROPDOWNMENU_MENU_VALUE == "display" then
			local checked, func
			if spc.Display == "Used/Total" then checked = true else checked = false end
				func = function() spc.Display = "Used/Total"; gf.Bags.update() end;
				gf.setInfo(nil,false,false,false,checked,"Used/Total","Used/Total",level,func,nil,nil,true)
			if spc.Display == "Free/Total" then checked = true else checked = false end
				func = function() spc.Display = "Free/Total"; gf.Bags.update() end;
				gf.setInfo(nil,false,false,false,checked,"Free/Total","Free/Total",level,func,nil,nil,true)
			if spc.Display == "Free" then checked = true else checked = false end
				func = function() spc.Display = "Free"; gf.Bags.update() end;
				gf.setInfo(nil,false,false,false,checked,"Free","free",level,func,nil,nil,true)
			if spc.Display == "Used" then checked = true else checked = false end
				func = function() spc.Display = "Used"; gf.Bags.update() end;
				gf.setInfo(nil,false,false,false,checked,"Used","used",level,func,nil,nil,true)
			if spc.Display == "Total" then checked = true else checked = false end
				func = function() spc.Display = "Total"; gf.Bags.update() end;
				gf.setInfo(nil,false,false,false,checked,"Total","total",level,func,nil,nil,true)
			
		end
		if UIDROPDOWNMENU_MENU_VALUE == "tradebags" then
			local checked, func
			if spc.CountTradeBagSlots then checked = true else checked = false end
				func = function() spc.CountTradeBagSlots=true; gf.Bags.update() end;
				gf.setInfo(nil,false,false,false,checked,"Yes","Yes",level,func)
			if spc.CountTradeBagSlots then checked = false else checked = true end
				func = function() spc.CountTradeBagSlots=false; gf.Bags.update() end;
				gf.setInfo(nil,false,false,false,checked,"No","No",level,func)
		end
	end
end

---------------------------
-- get bag info
---------------------------
function gf.Bags.getBagSlots(bag)
	local total, free = 0,0
	local bagType
	total = GetContainerNumSlots(bag);
	free, bagType = GetContainerNumFreeSlots(bag)
	return { total, total-free, free, gf.Bags.isTradeBag(bagType) }
end

---------------------------
-- is trade bag?
---------------------------
function gf.Bags.isTradeBag(bagType)
	if bagType == nil then return false end
	local BAGTYPE_PROFESSION = 0x0001 + 0x0002 + 0x0004 + 0x0008 + 0x0010 + 0x0020 + 0x0040 + 0x0080 + 0x0100 + 0x0200 + 0x0400 + 0x0800 + 0x1000 + 0x10000 + 0x100000
	if (bit.band(bagType, BAGTYPE_PROFESSION) > 0) then
		return true
	end
	return false
end

---------------------------
-- load on demand
---------------------------
if gv.loaded then
	gf.Enable("Bags")
end