---------------------------
-- lets simplify a bit..
---------------------------
local gf = Glance.Functions
local gv = Glance.Variables
local ga = Glance.Arrays
local gb = Glance.Buttons

---------------------------
-- create the button
---------------------------
gf.AddButton("Memory","LEFT")
local btn = gb.Memory
btn.text              = "Memory"
btn.events            = {"PLAYER_LOGIN"}
btn.enabled           = true
btn.update            = true
btn.click             = true
btn.onload            = true
btn.tooltip           = true
btn.timer5            = true
btn.timerTooltip      = true
btn.menu              = true
btn.save.perAccount = { ["collectGarbage"] = false, ["oneGlance"] = true }

---------------------------
-- shortcuts
---------------------------
local spa = btn.save.perAccount
local HEX = ga.colors.HEX
local tooltip = gf.Tooltip

---------------------------
-- variables
---------------------------
gv.memory = 0
gv.addons = {}
gv.gaddons = {}

---------------------------
-- timers
---------------------------
gf.AddTimer("Memory",0,5,true,nil,nil,nil)

---------------------------
-- update
---------------------------
function gf.Memory.update()
	if btn.enabled and gv.loaded then -- loaded keeps it from launching when defined	
		local total = 0
		UpdateAddOnMemoryUsage()
		for i=1, GetNumAddOns() do
			if IsAddOnLoaded(i) then
				local memory = GetAddOnMemoryUsage(i)
				total = total + memory
			end
		end
		gv.memory = total
		gf.setButtonText(btn.button,"Mem: ",gf.Memory.FormatMemory(total),nil,nil)
	end
end

---------------------------
-- tooltip
---------------------------
function gf.Memory.tooltip()
	Glance.Debug("function","tooltip","Memory")
	gf.Memory.update()
	local k,v,i
	local resort = false
	local acp = false
	for i=1, #gv.addons do
		if Glance.Timers.Memory[1] <= 1 then
			local mem = GetAddOnMemoryUsage(gv.addons[i][1])
			if gv.addons[i][1] == "Glance" and spa.oneGlance then
				local total = 0
				for j=1, #gv.gaddons do
					local gmemory = GetAddOnMemoryUsage(gv.gaddons[j][1])
					total = total + gmemory
				end
				mem = total
			end
			if gv.addons[i][2] ~= mem then
				if gv.addons[i][2] > mem then
					gv.addons[i][4] = "down"
				elseif gv.addons[i][2] < mem then
					gv.addons[i][4] = "up"
				end
				gv.addons[i][3] = "GRN"
				gv.addons[i][2] = mem
				resort = true
			else 
				gv.addons[i][3] = "LBL"
				gv.addons[i][4] = "steady"
			end
		else
			gv.addons[i][3] = "LBL"
			gv.addons[i][4] = "steady"
		end
	end
	if resort then
		table.sort(gv.addons, function(a, b) return a[2] > b[2] end)
		resort = false
	end
	tooltip.Title("Memory Usage", "GLD")
	for k, v in pairs(gv.addons) do
		if v[2] > 1000 then
			tooltip.Double("|T".."Interface\\Addons\\Glance_Memory\\"..v[4]..":0|t "..format("%s", v[1]), gf.Memory.FormatMemory(v[2]), v[3], "RED")
		elseif v[2] > 500 then
			tooltip.Double("|T".."Interface\\Addons\\Glance_Memory\\"..v[4]..":0|t "..format("%s", v[1]), gf.Memory.FormatMemory(v[2]), v[3], "YEL")
		else
			tooltip.Double("|T".."Interface\\Addons\\Glance_Memory\\"..v[4]..":0|t "..format("%s", v[1]), gf.Memory.FormatMemory(v[2]), v[3], "GRN")
		end
		if v[1] == "ACP" then
			acp = true
		end
	end
	tooltip.Space()
	tooltip.Double("Total Memory Usage: ", gf.Memory.FormatMemory(gv.memory), "WHT","WHT")	
	local tbl = {
		[1] = {["Recycle Memory"]=spa.collectGarbage},
		[2] = {["Single Entry for Glance"]=spa.oneGlance},
	}
	tooltip.Options(tbl)
	local showACP = nil
	if acp then showACP = "launch ACP" end
	--(left,shift-left,right,shift-right,other)
	tooltip.Notes("recycle memory",showACP,"change Options",nil,nil)
end

---------------------------
-- click
---------------------------
function gf.Memory.click(self, button, down)
	Glance.Debug("function","click","Memory")
	if (button == "LeftButton") then 
		if IsShiftKeyDown() then
			ShowUIPanel(ACP_AddonList)
		else
			gf.Memory.collectGarbage()
		end
	end
end

---------------------------
-- onload
---------------------------
function gf.Memory.onload()
	wipe(gv.addons)
	local i = 0
	UpdateAddOnMemoryUsage()
	if spa.oneGlance then
		local total = 0
		for i=1, GetNumAddOns() do
			local name, title = GetAddOnInfo(i)
			if gf.matchSingle(name,"Glance") then
				local memory = GetAddOnMemoryUsage(i)
				total = total + memory
				table.insert(gv.gaddons, {name, memory,"LBL","steady"})
			end
		end
		table.insert(gv.addons, {GetAddOnInfo("Glance"), total,"LBL","steady"})
	end
	for i=1, GetNumAddOns() do
		if IsAddOnLoaded(i) then
			local memory = GetAddOnMemoryUsage(i)
			local name, title = GetAddOnInfo(i)
			if not gf.matchSingle(name,"Glance") then
				table.insert(gv.addons, {GetAddOnInfo(i), memory,"LBL","steady"})
			elseif not spa.oneGlance then
				table.insert(gv.addons, {GetAddOnInfo(i), memory,"LBL","steady"})
			end
		end
	end
	table.sort(gv.addons, function(a, b) return a[2] > b[2] end)
	if spa.collectGarbage then
		gf.Memory.collectGarbage() 
	end
end

---------------------------
-- menu
---------------------------
function gf.Memory.menu(level,UIDROPDOWNMENU_MENU_VALUE)
	Glance.Debug("function","menu","Memory")
	level = level or 1
	if (level == 1) then
		gf.setMenuTitle("Memory Options")
		gf.setMenuHeader("Recycle Memory on Login","garbage",level)
		gf.setMenuHeader("Show single entry for Glance","one",level)
	end
	if (level == 2) then
		if gf.isMenuValue("garbage") then
			gf.setMenuOption(spa.collectGarbage==true,"On","On",level,function() spa.collectGarbage=true; end)
			gf.setMenuOption(spa.collectGarbage==false,"Off","Off",level,function() spa.collectGarbage=false; end)
		end
		if gf.isMenuValue("one") then
			gf.setMenuOption(spa.oneGlance==true,"On","On",level,function() spa.oneGlance=true; gf.Memory.onload() end)
			gf.setMenuOption(spa.oneGlance==false,"Off","Off",level,function() spa.oneGlance=false; gf.Memory.onload() end)
		end
	end
end

---------------------------
-- format memory usage
---------------------------
function gf.Memory.FormatMemory(usage)
	if usage > 1000 then
		return format(HEX.red.."%.2f "..HEX.white.."mb", usage/1024)
	elseif usage > 500 then
		return format(HEX.yellow.."%.2f "..HEX.white.."kb", usage)
	elseif usage > 0 then
		return format(HEX.green.."%.2f "..HEX.white.."kb", usage)
	end
end

---------------------------
-- garbage collection
---------------------------
function gf.Memory.collectGarbage()
	local current = collectgarbage("count")
	collectgarbage("collect")
	UpdateAddOnMemoryUsage()
	local garbage = current - collectgarbage("count")
	gf.sendMSG("Memory Recycled. ("..gf.Memory.FormatMemory(garbage)..")");
end

---------------------------
-- load on demand
---------------------------
if gv.loaded then
	gf.Enable("Memory")
end