--------------------------------------------------------------------
-- Interface Options Panel
--------------------------------------------------------------------

---------------------------
-- lets simplify a bit..
---------------------------
local gf = Glance.Functions
local gv = Glance.Variables
local ga = Glance.Arrays
local gb = Glance.Buttons
local gd = Glance.Data

---------------------------
-- create options
---------------------------
function gf.createOptionsPanel()

	-- panel list
	---------------------------
	Glance.Panels[1] = {"Glance",GetAddOnMetadata("Glance","Notes")}
	Glance.Panels[2] = {"General Settings","General configuration settings for Glance."}
	Glance.Panels[3] = {"Modules","Enable or disable the following modules in Glance. Individual options for modules can be accessed via Right-Click. Previously enabled modules will remain in memory until the UI is reloaded."}
	Glance.Panels[4] = {"Profiles","This is a very simple profile tool.  Click Save Profile to save this character's options to the profile.  Some modules do not allow settings to be saved.  The mount list, for instance, would not be the same for every character.  When you login to another character, come back to the Profiles option panel and click Load Profile to load the previously saved options.  Click Reload UI to register the changes."}
	
	-- create the panels
	---------------------------
	gf.createPanels()
	
	-- about text
	---------------------------
	Glance.Text[1] = {1,15,-85,"Version","GameFontNormal",""}
	Glance.Text[2] = {1,15,-100,GetAddOnMetadata("Glance","Version"),"GameFontHighlight",""}
	Glance.Text[3] = {1,15,-135,"Updated","GameFontNormal",""}
	Glance.Text[4] = {1,15,-150,GetAddOnMetadata("Glance","X-Updated"),"GameFontHighlight",""}
	Glance.Text[5] = {1,15,-185,"Author","GameFontNormal",""}
	Glance.Text[6] = {1,15,-200,GetAddOnMetadata("Glance","Author"),"GameFontHighlight",""}
	Glance.Text[7] = {1,15,-235,"Category","GameFontNormal",""}
	Glance.Text[8] = {1,15,-250,GetAddOnMetadata("Glance","X-Category"),"GameFontHighlight",""}
	Glance.Text[9] = {1,15,-285,"New In This Version","GameFontNormal",""}
	Glance.Text[10] = {1,15,-300,GetAddOnMetadata("Glance","X-New"),"GameFontHighlight",""}
	
	-- general options
	---------------------------
	Glance.Text[22] = {2,0,-60,"If you don't like Glance on top..","GameFontNormal",""}
	--Glance.Text[23] = {2,0,-75,"You must reload the UI for this option to take effect.","GameFontHighlight",""}
	Glance.CheckBoxes[8] = {2,15,-80,"showLow","Show Glance at the bottom of the UI",nil,function() 
		if _G["chk8"]:GetChecked() then gf.positionBar(0,true) else gf.positionBar() end end}
	
	-- UI Options
	---------------------------
	Glance.Text[11] = {2,0,-120,"Move the following to make room for Glance","GameFontNormal",""}
	Glance.Text[12] = {2,0,-135,"Glance will not release any unchecked frames to other addons until the UI is reloaded.","GameFontHighlight",""}
	Glance.CheckBoxes[1] = {2,15,-160,"movePlayer","Player Frame",nil,function() gf.moveUI() end, Glance_Local.Options.showLow}
	Glance.CheckBoxes[2] = {2,15,-180,"moveTarget","Target Frame",nil,function() gf.moveUI() end, Glance_Local.Options.showLow}
	Glance.CheckBoxes[3] = {2,15,-200,"moveBuffs","Buffs",nil,function() gf.moveUI() end, Glance_Local.Options.showLow}
	Glance.CheckBoxes[4] = {2,15,-220,"moveMinimap","Minimap",nil,function() gf.moveUI() end, Glance_Local.Options.showLow}
	
	-- other options
	---------------------------
	Glance.Text[13] = {2,0,-260,"Other Options","GameFontNormal",""}
	Glance.CheckBoxes[9] = {2,15,-280,"autoHide","Auto-Hide the bar until mouseover",nil,function() gf.autoHide(false); end,false}
	Glance.CheckBoxes[5] = {2,15,-300,"sendStats","Send stats to party members using Glance",nil}
	Glance.CheckBoxes[6] = {2,15,-320,"timePlayed","Show time played on login",nil}
	Glance.CheckBoxes[7] = {2,15,-340,"gameFont","Use the standard game font (Requires Restart)",nil}
	
	-- scale
	---------------------------
	Glance.Text[14] = {2,250,-375,"Select the scale of the Glance bar","GameFontNormal",""}
	gf.createSlider("FrameScale",2,Glance_Local.Options.frameScale,0.5,1.5,0.1,291,-455,gf.updateFrameScale)
	Glance.CheckBoxes[10] = {2,265,-390,"scaleTooltip","Scale the tooltips with the bar",nil}
	
	-- colors
	---------------------------
	Glance.Text[15] = {2,0,-375,"Select the colors of the Glance bar","GameFontNormal",""}
	gf.createSwatch("BarColor","Glance_Panel2",1,18,18,35,-410)
	Glance.Text[16] = {2,45,-396,"Bar Color","GameFontHighlight",""}
	gf.createSwatch("BarColorCombat","Glance_Panel2",2,18,18,35,-434)
	Glance.Text[17] = {2,45,-421,"Bar Color (Combat)","GameFontHighlight",""}
	gf.createSwatch("BarColorResting","Glance_Panel2",4,18,18,35,-458)
	Glance.Text[18] = {2,45,-446,"Bar Color (Resting)","GameFontHighlight",""}
	gf.createSwatch("BarBorder","Glance_Panel2",3,18,18,35,-482)
	Glance.Text[19] = {2,45,-471,"Bar Border Color","GameFontHighlight",""}
	
	-- reset color
	---------------------------
	gf.createOptionsButton(2,"GLance_Panel2_Reset","RESET",32,-512,function() 
		local r,g,b,a = unpack(gv.defaultFrameColor[1]);
		_G["GlanceSwatchBarColor"].texture:SetTexture(r, g, b, 1)
		r,g,b,a = unpack(gv.defaultFrameColor[2]);
		_G["GlanceSwatchBarColorCombat"].texture:SetTexture(r, g, b, 1)
		r,g,b,a = unpack(gv.defaultFrameColor[3]);
		_G["GlanceSwatchBarBorder"].texture:SetTexture(r, g, b, 1)
		r,g,b,a = unpack(gv.defaultFrameColor[4]);
		_G["GlanceSwatchBarColorResting"].texture:SetTexture(r, g, b, 1)
		Glance_Global.Options.frameColor = gv.defaultFrameColor
		gf.setBackground(1)
	end)
	
	-- profile text
	---------------------------
	Glance.Text[20] = {4,0,-130,"Current Profile set to:","GameFontNormal",""}
	Glance.Text[21] = {4,130,-130," ","GameFontHighlight","profile is not set.","Glance_Profile_Text"}
	
	-- profile buttons
	---------------------------
	gf.createOptionsButton(4,"GLance_Panel4_Save","Save Profile",30,-100,function() gf.saveProfile() end)
	gf.createOptionsButton(4,"GLance_Panel4_Load","Load Profile",150,-100,function() gf.loadProfile() end)
	gf.createOptionsButton(4,"GLance_Panel4_Reload","RELOAD UI",270,-100,function() StaticPopup_Show("Glance_RELOADUI") end)
	
	-- reload UI buttons
	---------------------------
	gf.createOptionsButton(2,"GLance_Panel2_ReloadUI","RELOAD UI",345,-582,function() StaticPopup_Show("Glance_RELOADUI") end)
	gf.createOptionsButton(3,"GLance_Panel3_ReloadUI","RELOAD UI",345,-582,function() StaticPopup_Show("Glance_RELOADUI") end)
	gf.createOptionsButton(4,"GLance_Panel4_ReloadUI","RELOAD UI",345,-582,function() StaticPopup_Show("Glance_RELOADUI") end)
	
	-- module descriptions frame
	---------------------------
	Glance.Frames.descFrame = CreateFrame("BUTTON", "Glance", Glance_Panel3)
	local tf = Glance.Frames.descFrame
	tf:SetWidth(275)
	tf:SetHeight(415)
	tf:SetPoint("TOPLEFT", 330, -70)
	tf:SetBackdrop(ga.backDrop)
	
	local t = tf:CreateTexture(nil, "BACKGROUND")
	t:SetTexture(0, 0, 0, .5)
	t:SetAllPoints(tf)
	tf.texture = t 	
	tf:Show()
	
	local fs = tf:CreateFontString()
	fs:SetFont(gv.fnt_file, 12)
	fs:SetHeight(400)
	fs:SetWidth(265)
	fs:SetNonSpaceWrap(true)
	fs:SetWordWrap(true)
	fs:SetJustifyH("LEFT")
	fs:SetJustifyV("TOP")
	tf:SetFontString(fs)
	
	-- create checkbox/scroll
	---------------------------
	gf.createTexts()
	gf.createCheckBoxes()
	gf.createScrollBars()
	
	-- load button options
	---------------------------
	for k, v in pairs(gb) do
		if gb[k].options then
			gf[k].options()
		end
	end
	
	-- profile stored text
	---------------------------
	if Glance_Profile.realm ~= nil and Glance_Profile.name ~= nil and Glance_Profile.date ~= nil and Glance_Profile.time ~= nil then
		_G["Glance_Profile_Text"]:SetText(Glance_Profile.realm.." \\ "..Glance_Profile.name.." on "..Glance_Profile.date.." at "..Glance_Profile.time)
	end
end

gf.createOptionsPanel()
gf.setOptionValues()